regulators: Enable phase fault detection

Modify the top level Manager class to perform phase fault detection
every 15 seconds.

If the chassis is powered on, phase faults will be detected in every
regulator device in the system.

Tested:
* Tested where no phase fault found for a regulator.
* Tested where an N phase fault found for a regulator.
* Tested where an N+1 phase fault found for a regulator.
* Tested where additional data was captured in phase fault error log.
* Verified detection occurs every 15 seconds
* Verified detection starts during power on after regulators are
  enabled.
* Verified detection stops during power off before regulators are
  disabled.
* Tested where no JSON configuration file was loaded.
* Tested when application was restarted while system was powered on.

Signed-off-by: Shawn McCarney <shawnmm@us.ibm.com>
Change-Id: I12ac16dfcf4f754e168ce1ff76795520f823349f
diff --git a/phosphor-regulators/src/manager.hpp b/phosphor-regulators/src/manager.hpp
index d9b62a0..c056b27 100644
--- a/phosphor-regulators/src/manager.hpp
+++ b/phosphor-regulators/src/manager.hpp
@@ -104,6 +104,16 @@
     void monitor(bool enable) override;
 
     /**
+     * Phase fault detection timer expired callback function.
+     */
+    void phaseFaultTimerExpired();
+
+    /**
+     * Sensor monitoring timer expired callback function.
+     */
+    void sensorTimerExpired();
+
+    /**
      * Callback function to handle receiving a HUP signal
      * to reload the configuration data.
      *
@@ -113,11 +123,6 @@
     void sighupHandler(sdeventplus::source::Signal& sigSrc,
                        const struct signalfd_siginfo* sigInfo);
 
-    /**
-     * Timer expired callback function
-     */
-    void timerExpired();
-
   private:
     /**
      * Clear any cached data or error history related to hardware devices.
@@ -211,9 +216,14 @@
     BMCServices services;
 
     /**
      * Event timer used to initiate regulator monitoring.
      */
-    Timer timer;
+    Timer phaseFaultTimer;
+
+    /**
+     * Event timer used to initiate sensor monitoring.
+     */
+    Timer sensorTimer;
 
     /**
      * List of D-Bus signal matches
@@ -211,9 +216,14 @@
 
     /**
-     * Event timer used to initiate regulator monitoring.
+     * Event timer used to initiate phase fault detection.
      */